==> pyUSIrest-0.2.2.tar.gz: pyUSIrest-0.2.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['python_jwt', 'requests', 'url-normalize']

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest', ]

setup(
    author="Paolo Cozzi",
    author_email='cozzi@ibba.cnr.it',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Software Development :: Libraries',
    ],
    description=("Python USI submission REST API contain all methods to "
                 "interact with EMBL-EBI Unified Submissions Interface"),
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='pyUSIrest',
    name='pyUSIrest',
    packages=find_packages(include=['pyUSIrest']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/cnr-ibba/pyUSIrest',
    version="0.2.2",
    zip_safe=False,
)

==> pyUSIrest-0.3.0.tar.gz: pyUSIrest-0.3.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['python_jwt', 'requests', 'url-normalize', 'dateutils']

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest>=3', ]

setup(
    author="Paolo Cozzi",
    author_email='paolo.cozzi@ibba.cnr.it',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description=("Python USI submission REST API contain all methods to "
                 "interact with EMBL-EBI Unified Submissions Interface"),
    long_description_content_type='text/x-rst',
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='pyUSIrest',
    name='pyUSIrest',
    packages=find_packages(include=['pyUSIrest', 'pyUSIrest.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/cnr-ibba/pyUSIrest',
    version="0.3.0",
    zip_safe=False,
)
